@@ -62,7 +62,7 @@ class DiscreteEnv(gym.Env):
 
     #set an initial state, sample a random row from df to get 1 observation (Xs(0), Xa(0))
     #the step def will update self.state according to some value
-    self.state=self.df.sample(n=1, random_state=1).values.reshape(3,)
+    self.state=None    #self.df.sample(n=1, random_state=1).values.reshape(3,)
 
     #introduce some (short) length (time steps)
     self.horizon=20
@@ -79,16 +79,19 @@ class DiscreteEnv(gym.Env):
 #it returns the next observation, the immediate reward, whether the episode is over (done) and additional information    
 #"action" argument is one value in the range of the action space (logit transform)
   def step(self, action):
+    
+    self.df.sample(n=1, random_state=1).values.reshape(3,) = self.state
     #compute rho
     Xsa=(self.thetas[0])+(self.thetas[1])*(self.state[0])+(self.thetas[2])*(self.state[1])
-    rho=(1/(1+np.exp(-Xsa)))
+    rho1=0.2   
+    rho2 = (1/(1+np.exp(-Xsa)))
 
     #apply a value from the action space on the state by means of some function that depends on action
     #the function
-    g = ((1/2)*(3-(2*(rho)))*(self.state[1])+(1-(2*(rho)))*((1+(self.state[1])**2)**0.5))
+    g = ((1/2)*(3-(2*(rho1)))*(self.state[1])+(1-(2*(rho1)))*((1+(self.state[1])**2)**0.5))
 
     #if action is 1 and rho (risk) high, intervene and discount Xa
-    if (action ==1) & (rho >= 0.5):
+    if (action ==1):  & (rho2 >= 0.5)
         new_Xa = g
     else:
         new_Xa = (self.state[1])  
